package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````:B4```````!``````````#"Q````
M`````````$``.``*`$``&``7``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````9`````````!D``````````0`````````!````
M!``````````````````````````````````````8`````````!@`````````
M$`````````$````%`````"``````````(``````````@````````[S,`````
M``#O,P`````````0`````````0````0`````8`````````!@`````````&``
M```````00P```````!!#`````````!`````````!````!@```""L````````
M(+P````````@O````````$`$````````Z!0`````````$`````````(````&
M````2*P```````!(O````````$B\````````H`$```````"@`0````````@`
M````````4.5T9`0```!4G0```````%2=````````5)T```````#D````````
M`.0`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````(*P````````@
MO````````""\````````X`,```````#@`P````````$`````````+VQI8B]L
M9"UM=7-L+7@X-E\V-"YS;RXQ```````````1````0`````0````(````(!P0
M``5`!((H`%`$D(8`A((A`"!)`@0)N((90;H$`@I`````00```$4```!)````
M2@```%````!1````4P````````!7````6````%D```!;````70```%\`````
M`````````*/I&01J?YI\ZM/O#L[>1RUOQ=\?+L6;MKB-\0[49-1\(?_D#MEQ
M6!SZH6Q@PN4_++(!BV]"^M>'XD?&`;OCDGQ5PSS2Q+F<0&>OS&8X\HL<Q(D%
MD(@'<--#1=7L,V+;[16,)<Q6I)N6I]VC:WZIG)O19<YMX*<""FL:GE`*BA!7
MH^#[20````````````````````````````````P````2````````````````
M`````````+,!```2`````````````````````````%4!```2````````````
M`````````````!L````2`````````````````````````)(!```2````````
M`````````````````",````2`````````````````````````"H````2````
M`````````````````````.8!```2`````````````````````````)X!```2
M`````````````````````````#,````@`````````````````````````$L`
M```2`````````````````````````%$````2````````````````````````
M`%@````2`````````````````````````.8"```2````````````````````
M`````-<"```2`````````````````````````&L"```2````````````````
M``````````P"```2`````````````````````````%\````2````````````
M`````````````*`"```2`````````````````````````&8````2````````
M`````````````````&X````2`````````````````````````(D"```2````
M`````````````````````'8````2`````````````````````````'P````2
M`````````````````````````(4````@`````````````````````````-`"
M```2`````````````````````````*$````2````````````````````````
M`*8````2`````````````````````````*<"```2````````````````````
M`````#D"```2`````````````````````````*T````2````````````````
M`````````"L"```2`````````````````````````#T#```2````````````
M`````````````%T"```2``````````````````````````4#```2````````
M`````````````````+0````2`````````````````````````/T"```2````
M`````````````````````&,!```2`````````````````````````,P````@
M`````````````````````````.(````2`````````````````````````,@"
M```2`````````````````````````$D"```2````````````````````````
M`.<````2`````````````````````````.T````@````````````````````
M`````)0"```2``````````````````````````<!```2````````````````
M`````````(,!```2``````````````````````````P!```2````````````
M`````````````'D"```2`````````````````````````'(!```2````````
M`````````````````!(!```2`````````````````````````",!```2````
M``````````````````````<"```2`````````````````````````'<````2
M`````````````````````````!@"```2`````````````````````````%("
M```2`````````````````````````/8"```2````````````````````````
M`"D!```2`````````````````````````.X"```2````````````````````
M``````("```2`````````````````````````,$!```2````````````````
M`````````#T!```2`````````````````````````$X!```2````````````
M`````````````!<#```A`!4`:,`````````(`````````!(#```2``H`N",`
M``````"R`0```````-,!```2``L`YU,````````!`````````'\#```2``H`
MJS$```````#2!0```````"L$```2``H`R3H```````!.`````````%P#```2
M``H`J"P````````%`````````.D#```2``<``"`````````!`````````*(#
M```2``H`?3<```````!,`P````````\$```2``H`K2P```````"T`0``````
M`-H#```0`!4`8,```````````````````&T#```2``H`%3$```````"6````
M`````(P#```2``H`4RL````````K`````````)0#```2``H`NC````````!$
M`````````+@#```2``H`<5$```````#^`````````,T#```2``H`82X`````
M```6`````````"8$```0`!4`"-$``````````````````"(#```2``H`@"4`
M```````E`````````!@#```1`!4`:,`````````(`````````.\#```2``H`
M=RX```````"?`````````!0````1`!$`0+P````````(`````````!D#```A
M`!4`:,`````````(`````````,,#```1`!0`6,`````````(``````````@$
M```0`!0`8,```````````````````-\#```0``H`:B4`````````````````
M`.8#```2``H`(U$```````!.`````````/<!```1`!4`<,`````````$````
M`````!H#```A`!4`:,`````````(`````````"L#```2``H`_C`````````7
M`````````+T````B`````````````````````````$8#```2``H`PBL`````
M``#F`````````!P$```2``H`;U(```````!6`0```````-D!```1`!4`8,``
M```````!`````````/L#```2``H`%B\```````"D`0````````!L:6)P97)L
M+G-O`&]P96YD:7(`<W1D97)R`')E86QL;V,`86-C97-S`'-N<')I;G1F`%]?
M9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K`&=E='!I9`!S=')C;7``=6YL
M:6YK`&UE;6UO=F4`<W1R;F-M<`!L<W1A=`!C;&]S961I<@!?251-7V1E<F5G
M:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S='(`<W1R8VAR`')E861L:6YK
M`%]?8WAA7V9I;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?:6YF;P!E>&ET`&-L
M;W-E`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`<F5A9`!R;61I<@!?7V5R
M<FYO7VQO8V%T:6]N`&UK9&ER`'!T:')E861?9V5T<W!E8VEF:6,`7U]S=&%C
M:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET
M,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V
M`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R
M<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`
M4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?
M=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N
M`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?
M1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L
M7V%L;&]C`&QI8F,N;75S;"UX.#9?-C0N<V\N,0!F<')I;G1F`'-T<F1U<`!P
M=&AR96%D7V%T9F]R:P!R96%D9&ER`'-P<FEN=&8`<W1R=&]K`'-T<FYC<'D`
M7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV:7)O;@!?<W1A<G1?8P!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R
M7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D:7(`
M>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!S
M:&%?=7!D871E`&UY7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?<W1A<G0`
M<VAA7VEN:70`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P87)?
M9FEN9'!R;V<`<VAA7V9I;F%L`%]E;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O
M<&5R;#4O8V]R95]P97)L+T-/4D4``````,`````````(``````````#`````
M````(,`````````(`````````.)@````````*,`````````(`````````-M@
M````````,,`````````(`````````!YB````````.,`````````(````````
M`/A@````````0,`````````(`````````"9B````````6,`````````(````
M`````+MB````````P+\````````&````"@``````````````R+\````````&
M````&0``````````````T+\````````&````7```````````````V+\`````
M```&````)P``````````````X+\````````&````+```````````````Z+\`
M```````&````,0``````````````\+\````````&````,@``````````````
M^+\````````&````-P``````````````0+P````````%````4P``````````
M````8,`````````%````7P``````````````:,`````````%````40``````
M````````<,`````````%````60```````````````+X````````'`````0``
M````````````"+X````````'`````@``````````````$+X````````'````
M`P``````````````&+X````````'````!```````````````(+X````````'
M````!0``````````````*+X````````'````!@``````````````,+X`````
M```'````!P``````````````.+X````````'````"```````````````0+X`
M```````'````"0``````````````2+X````````'````"P``````````````
M4+X````````'````#```````````````6+X````````'````#0``````````
M````8+X````````'````#@``````````````:+X````````'````#P``````
M````````<+X````````'````$```````````````>+X````````'````$0``
M````````````@+X````````'````$@``````````````B+X````````'````
M$P``````````````D+X````````'````%```````````````F+X````````'
M````%0``````````````H+X````````'````%@``````````````J+X`````
M```'````%P``````````````L+X````````'````&```````````````N+X`
M```````'````&@``````````````P+X````````'````&P``````````````
MR+X````````'````'```````````````T+X````````'````'0``````````
M````V+X````````'````'@``````````````X+X````````'````'P``````
M````````Z+X````````'````(```````````````\+X````````'````(0``
M````````````^+X````````'````(@```````````````+\````````'````
M(P``````````````"+\````````'````)```````````````$+\````````'
M````)0``````````````&+\````````'````)@``````````````(+\`````
M```'````*```````````````*+\````````'````*0``````````````,+\`
M```````'````*@``````````````.+\````````'````*P``````````````
M0+\````````'````+0``````````````2+\````````'````+@``````````
M````4+\````````'````+P``````````````6+\````````'````,```````
M````````8+\````````'````,P``````````````:+\````````'````-```
M````````````<+\````````'````-0``````````````>+\````````'````
M-@``````````````@+\````````'````.```````````````B+\````````'
M````.0``````````````D+\````````'````.@``````````````F+\`````
M```'````.P``````````````H+\````````'````/```````````````J+\`
M```````'````/0``````````````L+\````````'````/@``````````````
MN+\````````'````/P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!0Z'\&``#HNC,``%C#````_S7:G0``_R7<G0``#Q]``/\EVIT``&@`````
MZ>#_____)=*=``!H`0```.G0_____R7*G0``:`(```#IP/____\EPIT``&@#
M````Z;#_____);J=``!H!````.F@_____R6RG0``:`4```#ID/____\EJIT`
M`&@&````Z8#_____):*=``!H!P```.EP_____R6:G0``:`@```#I8/____\E
MDIT``&@)````Z5#_____)8J=``!H"@```.E`_____R6"G0``:`L```#I,/__
M__\E>IT``&@,````Z2#_____)7*=``!H#0```.D0_____R5JG0``:`X```#I
M`/____\E8IT``&@/````Z?#^____)5J=``!H$````.G@_O___R52G0``:!$`
M``#IT/[___\E2IT``&@2````Z<#^____)4*=``!H$P```.FP_O___R4ZG0``
M:!0```#IH/[___\E,IT``&@5````Z9#^____)2J=``!H%@```.F`_O___R4B
MG0``:!<```#I</[___\E&IT``&@8````Z6#^____)1*=``!H&0```.E0_O__
M_R4*G0``:!H```#I0/[___\E`IT``&@;````Z3#^____)?J<``!H'````.D@
M_O___R7RG```:!T```#I$/[___\EZIP``&@>````Z0#^____)>*<``!H'P``
M`.GP_?___R7:G```:"````#IX/W___\ETIP``&@A````Z=#]____)<J<``!H
M(@```.G`_?___R7"G```:",```#IL/W___\ENIP``&@D````Z:#]____);*<
M``!H)0```.F0_?___R6JG```:"8```#I@/W___\EHIP``&@G````Z7#]____
M)9J<``!H*````.E@_?___R62G```:"D```#I4/W___\EBIP``&@J````Z4#]
M____)8*<``!H*P```.DP_?___R5ZG```:"P```#I(/W___\E<IP``&@M````
MZ1#]____)6J<``!H+@```.D`_?___R5BG```:"\```#I\/S___\E6IP``&@P
M````Z>#\____)5*<``!H,0```.G0_/___R5*G```:#(```#IP/S___\E0IP`
M`&@S````Z;#\____)3J<``!H-````.F@_/___R4RG```:#4```#ID/S___\E
M*IP``&@V````Z8#\____)2*<``!H-P```.EP_/___R4:G```9I#_)2*<``!F
MD/\E(IP``&:04TB#["")?"0<2(U\)!Q(B70D$$B-="002(E4)`A(C50D".AQ
M_O__2(LU$IP``$B+/0.<``!(B?+H^_S__X`]9)P```!U->B]_?__2(D%]JP`
M`$B%P'4*OP$```#H1_[__TB)Q^B?_O__BSU)G```Z!3____&@-$)````BSTW
MG```2(T==3X``.C[_O__BSTEG```@(@Z!````NCI_O__@(@Z!````8M$)!R-
M>`5(8_](P><#Z"_^__](BWPD$#')QP5NK```!````$B)!5^L``!(BQ=(B5@(
M2(T=(3X``$B)6!A(B1!(BQ6SFP``2(E0$(M4)!Q(_\$YRGX13(L$SXUQ!$AC
M]DR)1/#XZ^B-2@1%,<"#P@-(BSTKK```2&/)2(TUGP8``$C'1,CX`````$B)
MP>AP_/__B<.%P'4.2(L]`ZP``.A^_?__B<-(BSWUJP``Z`#]__\QP$B-/7P[
M``#H%`(``$B%P'4N2(,]S:L```!U$TB-/18[``#H^0$``$B)!;BK``!(BSVQ
MJP``2(7_=`7H>!4``$B+/:BK``#H`_[__^C>^O__2(/$((G86\-(,>U(B>=(
MC371E@``2(/D\.@`````4$B-5PA(BS=%,<E,C055+@``2(T-9_K__TB-/1C^
M___H>_S__TB-/;2:``!(C06MF@``2#GX=`Y(BP4)F@``2(7`=`+_X,-(C3V2
MF@``2(TUBYH``+D"````2"G^2,'^`TB)\$B92/?Y2(G&2(7`=`Y(BP7HF0``
M2(7`=`+_X,.`/7F:````=7M52(,]OID```!(B>5!5%-T#$B+/=^9``#H@OW_
M_TB-!0.6``!(C1T$E@``2"G#28G$2,'[`TC_RTB+!4":``!(.=AS$$C_P$B)
M!3&:``!!_Q3$Z^3H0____TB#/5:9````=`Q(C3T=>```Z"C]__];05S&!?Z9
M```!7</#2(,]2YD```!T&%5(C34)F@``2(T]\G<``$B)Y>@*_?__7>D;____
M05=!5D%50515,>U344B%_W1E3(LUHYD``$B)^DV%]G16B@*$P'0)/#UT!4C_
MPNOQ*?I)B?=)B?U-B?1(8]I)BRPD2(7M=#!(B=I,B>Y(B>_H3_K__X7`=1B`
M?!T`/74132GT2(UL'0%)P?P#18DGZP9)@\0(Z\=:2(GH6UU!7$%=05Y!7\-(
M@^P89$B+!"4H````2(E$)`@QP$B-="0$Z%S___](BU0D"&1(,Q0E*````'0%
MZ!O\__](@\08PU532(G[2(/L&&1(BP0E*````$B)1"0(,<!(C6PD!#'`2(GN
M2(G?Z!?___](A<!T(DAC5"0$2(L%PI@``$B-!-!(BU`(2(D02(72=-)(@\`(
MZ^Y(BT0D"&1(,P0E*````'0%Z*_[__](@\086UW#059!54%454B)_5-(B?-(
M@^P09$B+!"4H````2(E$)`@QP(`^/74#2/_#28/._T4Q[4B-="0$2(G?1(GH
M3(GQ\JY(B>](]]%.C20QZ(3^__](B<)(A<!T,TB)QTR)\42)Z/*N28G-2??5
M30'U33GE#X*E````,<"*#`.(#`)(_\"$R77S,<#I#P$``$R+-?Z7```QP$&)
MQ4C_P$F#?,;X`'7R08UU`DAC]DC!Y@.#/52H````=!Q,B??HNO?__TB)!<N7
M``!(A<!U.(/(_^G(````QP4LJ````0```$B)]^AT^/__2(7`=.%)8]5,B?9(
MB<=(P>(#Z&WX__](B06.EP``2(L%AY<``$ECU4C'1-`(`````$2);"0$2(GH
MBA"$TG0*@/H]=`5(_\#K\$@IZ$AC3"0$2(L55)<``$B828U\!`),C2S*Z`SX
M__])B44`2(7`#X1Q____2&-4)`1(BP4KEP``2(L$T$C_Q8I5_TB-2`&($(#Z
M/70)A-)T!4B)R.OFQ@`],<"*%`.(%`%(_\"$TG7SZ>K^__](BUPD"&1(,QPE
M*````'0%Z/GY__](@\006UU!7$%=05[#059!54%455-(@>R@````9$B+!"4H
M````2(F$))@````QP$B%_P^$[````(`_`$B)_0^$X````.A0]O__28/-_TF)
MQ$B%P`^$RP```$R)Y^CX]O__2(7`#X2J````2(U8$TB--04V``!(B=_HS/;_
M_X7`=-A(C37Q-0``2(G?Z+GV__^%P'3%,<!(B>],B>GRKDB)WTB)RDR)Z?*N
M2/?22(G(2/?0C3P02&/_Z.SV__](B=E(B>I(C36R-0``28G&2(G',<#H\OC_
M_TR)]TB-="0(Z*7X__],B??_P'07BT0D("4`\```/0!```!U!^@-____ZP7H
MDO;__TR)]^AJ^/__Z47___],B>?HW?;__TB)[^@E^/__2(N$))@```!D2#,$
M)2@```!T!>B]^/__2('$H````%M=05Q!74%>PU-(B?M(@>R@````9$B+!"4H
M````2(F$))@````QP$B-="0(Z'7V__^%P'4QBU0D(('B`/```('Z`$```'0(
M@?H`H```=1F^`@```$B)W^A*]?__A<`/E,`/ML#K`C'`2(N,))@```!D2#,,
M)2@```!T!>@V^/__2('$H````%O#4(L]%I4``.CA]___2(L5@I0``$%82(T-
MV7$``$B--9,T``!(B<?IHO?__U"+/>N4``#HMO?__TB)Q^C!____BSW8E```
MZ*/W__],C040-P``13')05I,B<%(C17*"P``2(TU:S0``$B)Q^G.]/__55-(
M@>P8(```9$B+!"4H````2(F$)`@@```QP$B-;"0&Z-CT__],C05+-```O@$0
M``!(B>^)P4B-%3XT```QP.AY]/__@_C_=00QP.MV2&/02('Z`!```'8"#PN%
MP'CJ2(V<)`<0``!(B>^Z`!```$B)WNCV]?__2(G%A<!XRXUX`4AC_^CD]/__
M2(7`=+M(8]5(.=AS"4B-#!!(.<MRND@YV'8)2(T,$T@YR'*L@?T!$```?Z2)
MT4B)QTB)WO.DQ@00`$B+M"0((```9$@S-"4H````=`7HXO;__TB!Q!@@``!;
M7</I%?___T%7059!54%454B)_4B-/8HS``!32(GS2('LJ!```&1(BP0E*```
M`$B)A"28$```,<#H3_K__[XO````2(GO28G%Z.WT__](A<!T%DB)[DB-/5$S
M```QP.C/^O__Z28!```QP$B)[TB--48S``!(@\G_\JY(B=],C3W7,@``2(G*
M2/?21(UR_^CW]?__2(G#2(7;=+>`.P!U`TR)^TV%[7032(G>3(GOZ'?S__^%
MP`^$O0```#'`2(/)_TB)W_*N2(G*2/?2C4+_2&/0@'P3_R]U"__(2&/0Q@03
M`.OK0HU$,`$]_P\```^/7O___TR-I"28````28GI2(G9,<!,C06Q,@``2(T5
MF3,``+X`$```3(GGZ+OR____P#T`$```=@(/"TB-="0(3(GGZ#/U__^%P'4]
MBT0D("4`\```/0"```!U+;X!````3(GGZ'+R__^%P'4<3(GF2(T]1S(``.C'
M^?__3(GGZ'?S__](B<7K%DB--3LR```Q_^@$]?__2(G#Z0C___](BY0DF!``
M`&1(,Q0E*````$B)Z'0%Z#'U__](@<2H$```6UU!7$%=05Y!7\-(B?B*%X32
M=`Q(_\>`^B](#T3'Z^[#2(7_=$N`/P!(B?YT0TB#R?\QP/*N2/?12(U4#OY(
M.=9S'8`Z+W4-2/_*Z_%(B<)(.<9S"X`Z+TB-0O]U[^LB2#G6=1V`/B](C3V=
M,0``=0=(C3TS,0``Z;WR__^`.B]U"$C_RD@YUG+S2"GR2(U"`D@]`!```'<D
M2/_"2('Z`!```'8"#PM02(T]VY$``.@V\___2(T%SY$``%K#,<##4TB--0)N
M``"Y(@```$B#[#!D2(L$)2@```!(B40D*#'`2(U\)`9(C5PD!O.D2(T]&C$`
M`.@;^/__,<!(C3T5,0``Z`WX__\QP$B-/0\Q``#H__?__S'`2(T]"C$``.CQ
M]___,<!(C3T#,0``Z./W__\QP$B-/04Q``#HU??__S'`2(T]K#```.C']___
M,<!(C3WU,```Z+GW__\QP$B-/?$P``#HJ_?__S'`2(T][3```.B=]___,<!(
MC3U],```Z(_W__\QP$B-/=LP``#H2??__TB%P'012(G&2(T]LS```#'`Z-GW
M__\QP$B-/<@P``#H)??__TB%P'012(G&2(T]QC```#'`Z+7W__](C3W#,```
M,<#H`??__TB-/1(P``!(B<9(A<!U'3'`2(T]M#```.CD]O__2(7`=`Y(B<9(
MC3U$,```,<#K)$B->Q&Z"@```$B--9TP``#HVO#__X7`=1!(C7,;2(T]'#``
M`.A.]___,<!(C36&,```2(T]ZR\``.@Y]___2(M$)"AD2#,$)2@```!T!>C,
M\O__2(/$,%O#@SV/CP``_W4T44B-/=8O```QP.A@]O__,=)(A<!T$(H`/#`/
ME<$QTH3`#Y7"(<J)%6&/``"+!5N/``!:PXL%4X\``,-1Z(SR__^)Q^CU\/__
M2(7`=`-(BP!:PT%4,<!52(G]2(T]]R\``%/H"/;__TB)[DB%P'1B@#@`2(G#
M=%I(B<?H;O#__TB%P'5?2(/._TB)[TB)\?*N2(G?2(G*2(GQ\JY(]])(B<A(
M]]!(C3P"Z,#O__](C37:+P``28G82(GJ28G$2(G'2(T-UBX``#'`Z+_Q__],
MB>9;2(T]?R\``%TQP$%<Z3+V__];74%<PT%72(TU;(X``+D,````059!54F)
M_4%455-(@>Q8@0``9$B+!"4H````2(F$)$B!```QP$B-!4TO``!(C7PD2$C'
M1"0H`````/.E2(E$)!A(C04`+@``2(T]0BX``$B)1"0@2(T%(R\``$B)1"0P
M2(T%'"\``$B)1"0X,<!(QT0D0`````#H_?3__TB%P'0@@#@`2(G#=!A(B<?H
MR_[__TB)W^@^[___2(G%Z?8$```QP$B-;"0PZ)C^__](B<-(A<!U.4B+?0!(
MA?]T*3'`Z+3T__](A<!U!DB#Q0CKY8`X`'3U2(G'Z/KN__](B<-(A<!TY>L'
M2(T=A"X``#'`2(G?3(TEDBX``$B#R?_RKDCWT4B-?`G_Z&KN__](B<5)B<8/
MMA.$TG063(GW3(GF,<!(_\/H;?#__TF#Q@+KXTR-9"1(28L<)$B%VW0N2(G?
M,<#H,?3__TB)PTB%P'0C@#@`=!Y(B<?HO??__X7`=!)(B=_H;N[__TB)PTR-
M="08ZS!)@\0(Z[Q-BR9-A>1T)T&`/"0`="!,B>?HBO?__X7`=`M,B>?H.^[_
M_TB)PTF#Q@A(A=MTT4B#SO\QP$B)WTB)\?*N2(GO2(G*2(GQ\JY(]])(B<A(
M]]!$C;P0`@0``$UC_TR)_^B:[?__28GI3(T%JBT``$B-#;LL``!(B<=)B<1(
MB=HQP$B--98M``#HDN___[[``0``3(GGZ"7O____P'4LZ`SO__]$BP!!@_@1
M=!Y)BU4`2(L]6(@``$R)X3'`2(TU9"T``.AW[O__ZS!(C70D>$R)Y^AH[?__
M08G&A<!T(TF+50!(BSTFB```3(GA,<!(C35M+0``Z$7N__\Q[>D>`P``BX0D
MD````"4`\```/0!```!URHN<))0```#H/^___SG#=;J+A"20````)?\!```]
MP`$``'6G3(G_Z,#L__](C3VO+```2(G%,<#HL?+__TB%P'4&38M]`.L<2(G'
MZ/SL__])BWT`2(G&Z`WX__])B<=(A<!TWDB#R?\QP$R)__*N2(G*2/?22(U:
M_X/[`WYF2&/#2(TU&BT``$F-?`?\Z/KK__^%P'5.@_L$=`Z#ZP1(8]M!@'P?
M_R]U.TF+70A(A=MT,C'`2(/)_TB)W_*N2(G*2/?22(U"_TB#^`-V%TB-?!/[
M2(TUSBP``.BNZ___A<!,#T3[,<#HB_O__X7`#X5H`0``,?9,B?_H7^S__XG#
MA<`/A%0!``"Z`@```$C'QN[___^)Q^A2Z___3(VL)$@!``"Z!@```(G?3(GN
MZ#OM__^`O"1(`0```'5C@+PD20$``$-U68"\)$H!``!!=4^`O"1+`0``0W5%
M@+PD3`$``$AU.X"\)$T!``!%=3&Z`@```$C'QL;___^)W^CLZO__NBD```!,
MB>Z)W^C=[/__3(T-VBP``$V)Z.F=````,=(Q]HG?Z,/J__\QP.@O&P``28G'
MN@"```!,B>Z)W^BJ[/__A<!^#XG"3(GN3(G_Z%H;``#KWHG?3(VT)`L!```Q
MV^AF[/__3(VL)!\!``!,B?Y,B??H,AP``$R-/0$K``!-B>A!#[84'DR)[S'`
M3(G^2/_#3(E$)`A)@\4"Z.OL__](@_L43(M$)`AUU\:$)$<!````3(T--2P`
M`$B-#=PI``!,B>)(B>\QP$B--5LK``#HMNS__^F0````2(TU<RH``$B-/?0I
M```QP.@D\?__2(T=^2L``.@`ZO__3(T-[2L``$R)XDB-#9$I``!!B<!(C34D
M*P``2(GO,<#H:^S__[[``0``2(GOZ/[K____P'4YZ.7K__^#.!%U+^B[Z?__
M0?_&3(GB2(GO08G`4#'`2(T-1RD``%-%B?%(C37G*@``Z"7L__]:6>NV3(GG
MZ,GK__](C3T,*0``2(GN,<#HD/#__TB)[^C%^?__2(N4)$B!``!D2#,4)2@`
M``!(B>AT!>@5[/__2('$6($``%M=05Q!74%>05_#055!5%534HL]YH@``.BQ
MZ___BSW;B```2(G#Z*/K__^*D[@```!(C3W;*```B)"Y````,<#H>^___TB%
MP'0+@#@Q=0:`>`$`=`<QP.A(]___BSV<B```Z&?K__^Y"P```+H!````2(TU
M0"H``$B)Q^C>Z?__2(7`=36+/7.(``#H/NO__[D#````N@$```!(C34<*@``
M2(G'Z+7I__](B<-(A<`/A<X```#I$`$``$B+0!"[`0```$R+8"@Y';&8``!$
MC6O_BSTGB```?AKH\.K__S')26/53(GF2(G'Z*#H__](A<!U%(L%A9@``/_(
M1#GH=86[`0```.M62(LHBT4,)0`$(``]``0``'4&2(M%$.L=BSW9AP``Z*3J
M__^Y`@```#'22(GN2(G'Z,+J__](BPTSF```2&/32(G&2(L\T>@,Z/__A<!U
MG?_#Z6K___\Y'1N8``"+/96'```/CA;____H6NK__TR)YO_#2(G'Z#WG___K
MVDB+0!"+/7&'``!(BRCH.>K__TB-%2,I``!(B<=(B>[HU^C__TB+0Q!(BQCV
M0PY`=!:+/42'``#H#^K__TB)WDB)Q^C4Y___BSTNAP``Z/GI__^Y`P```+H!
M````2(TUWB@``$B)Q^APZ/__2(G%2(7`#X2'````2(T]X"8``#'`Z+CM__](
MB<-(A<!T&DB+11"+/>2&``!(BRCHK.G__TB)VDB)[NM/Z"'R__^+/<F&``!(
MA<!(B<-(BT40="!(BRCHA>G__TB)VDB)QTB)[N@GZ/__2(G?Z"_I___K($B+
M%0Z7``!(BQA(BRKH6^G__TB)WDB)ZDB)Q^C]Y___BSUWA@``Z$+I__^Z`0``
M`$B--2XH``!(B<?H3N;__XL]6(8``$B)P^@@Z?__2(T5)B@``$B)WDB)Q^B^
MY___BSTXA@``Z`/I__](C3T&)@``QH"Y`````#'`Z.#L__](B06?E@``2(7`
M=21(BSV#E@``Z$'W__](B06'E@``2(7`=0Q(C3W6)P``Z![F__](BSUOE@``
MOL`!``#H7>C__XU0`8/Z`78F@_@1="&)P4B+!3^6``!(BQ5(E@``2(T]O2<`
M`$B+,#'`Z-_E__]86UU!7$%=PU532(G[4>BC\___2(G'Z(7S__](B<4QP.C4
M]?__A<!T*4B%VW0D@#L`=!](C35/)@``2(GOZ*WF__](.>AU"UI(B=];7>F!
M[O__6%M=PT%7,<E!5D%505154TB![)@"``!D2(L$)2@```!(B80DB`(``#'`
M3(M$#SB+5`\X2(U$)`@/RHG33(G"3(G&2,'J*$C![B!(B1Q(2<'H.('B`/\`
M`$P)PDF)\$C!Y@A)P>`8@>8``/\`18G`3`G"2`GR2(E43!!(@\$(2(/Y0'6F
M2(VT)`@"``!(BU!H2#-00$B#P`A(,U`(2#-0^$B-#!)(P>H?"<I(B5!X2#GP
M==E,BQ=(BU\02(MW($B+;QA,B=!,B=),BT\(2,'J&TC!X`5("=`#1"0(C90P
MF7F"6DB)V$B+="002#'H3"'(2(VT-9EY@EI(,>A$C1P"3(G*3(G(2,'H`DC!
MXAY-B=A("<)(B=A)P>@;B=%(,<A,(=!(,=A(`?!,B=Y(P>8%3`G&1(TT!DR)
MUDR)T$C!YAY(P>@"38GT2`GP2(MT)!A)P>P;2#'"08G`3"':2(VT,YEY@EI(
M,<I(`?),B?9(P>8%3`GF1(TD%DR)WDG!ZP)(BU0D($C!YAY,"=Y(C901F7F"
M6DR)X4@Q\$&)\TPA\$PQP$C!Z1M(`=!,B>)(P>(%2`G*3(GQ2<'N`DC!X1Y$
MC2P"2(M$)"A,"?%,B>I(,<Y)C80`F7F"6DC!ZAM!B<Y,(>9,,=Y(`<9,B>A(
MP>`%2`G03(GB2<'L`DC!XAY$C00P2(M$)#!,">),B<9(,=%)C80#F7F"6DC!
M[AM!B=1,(>E,,?%(`<%,B<!(P>`%2`GP1(T<"$R)Z$G![0)(BTPD.$C!X!Y,
MB=Y,">A)C8P.F7F"6D@QPD&)Q4PAPDPQXD@!RDR)V4C!X05(P>X;2`GQ3(G&
M2<'H`DC!YAY$C3012(M4)$!,"<9,B?%(,?!)C904F7F"6DC!Z1M!B?!,(=A,
M,>A(`=!,B?)(P>(%2`G*3(G92<'K`DC!X1Y$C20"2(M$)$A,"=E,B>)(,<Y)
MC80%F7F"6DC!ZAM!B<M,(?9,,<9(`<9,B>!(P>`%2`G03(GR2<'N`DC!XAY$
MC2PP2(M$)%!,"?),B>Y(,=%)C80`F7F"6DC![AM!B=9,(>%,,=E(`<%,B>A(
MP>`%2`GP1(T$"$R)X$G![`)(BTPD6$C!X!Y,B<9,">!)C8P+F7F"6DC![AM(
M,<)!B<1,(>I,,?)(`<I,B<%(P>$%2`GQ3(GN2<'M`DC!YAY$C1P12(M4)&!,
M">Y,B=E(,?!)C906F7F"6DC!Z1M!B?5,(<!,,>!(`=!,B=I(P>(%2`G*3(G!
M2<'H`DC!X1Y$C30"2(M$)&A,"<%,B?)(,<Y)C80$F7F"6DC!ZAM!B<A,(=Y,
M,>Y(`<9,B?!(P>`%2`G03(G:2,'B'DG!ZP)$C20P2(M$)'!,"=I,B>9(,=%)
MC80%F7F"6DC![AM!B=-,(?%,,<%(`<%,B>!(P>`%2`GP1(TL"$R)\$G![@)(
MBTPD>$C!X!Y,B>Y,"?!)C8P(F7F"6DC![AM(,<)!B<9,(>),,=I(`<I,B>E(
MP>$%2`GQ3(GF2<'L`DC!YAY$C0012(N4)(````!,">9,B<%(,?!)C903F7F"
M6DC!Z1M!B?1,(>A,,?!(`=!,B<)(P>(%2`G*3(GI2<'M`DC!X1Y$C1P"2(N$
M)(@```!,">E,B=I(,<Y)C80&F7F"6DC!ZAM!B<U,(<9,,>9(`<9,B=A(P>`%
M2`G03(G"2<'H`DC!XAY$C30P2(N$))````!,"<),B?9(,=%)C80$F7F"6DC!
M[AM!B=!,(=E,,>E(`<%,B?!(P>`%2`GP1(TD"$R)V$G!ZP)(BXPDF````$C!
MX!Y,B>9,"=A)C8P-F7F"6DC![AM(,<)!B<-,(?),,<)(`=%,B>)(P>(%2`GR
M3(GV2<'N`DC!YAZ)TDP)]D@!RDB+C"2@````2#'P08G53"'@28V,")EY@EI-
MB>A,,=A)P>@;2`'!3(GH2,'@!4P)P$V)X$G![`))P>`>B<!-">!)B?1(`<B)
M]DTQQ(G!2`.T)+````!$,>),BZ0DJ````$^-G".AZ]EN28G,3`':28G+2<'L
M&TG!XP5-">-%B=M,`=I-B>M)P>T"2<'C'D&)U$T)ZTV)Q46)P$P#A"2X````
M33'=1#'H38GE2(VT!J'KV6Y,B>!)P>T;2,'@!4P)Z(G`2`'P2(G.2,'I`DC!
MYAY!B<5("<Y,B=E%B=M(,?$QRDP#G"3`````28V,$*'KV6Y,B>I-B>A)P>@;
M2,'B!4P)PHG23(T$$4R)X4G![`)(P>$>1(G"3`GA28GTB?9(`[0DR````$DQ
MS$0QX$F)U$V-G`.AZ]EN2(G02<'L&TC!X`5,">")P$V-)`-,B>A)P>T"2,'@
M'D6)XTP)Z$F)S8G)2`.,)-````!),<5%,>A-B=U.C80&H>O9;DR)WDG![1M(
MP>8%3`GNB?9,`<9)B=!(P>H"2<'@'D&)]4D)T$B)PHG`3#'"03'43(GJ3HVD
M(:'KV6Y,B>E(P>(%2,'I&T@)RHG228T,%$R)VDC!XAY)P>L"08G,2`.$)-@`
M``!,"=I-B<-%B<!,`X0DX````$DQTT0QWDV)XTB-M#"AZ]EN3(G@2<'K&TC!
MX`5,"=B)P$@!\$R)[DG![0)(P>8>08G#3`GN28G5B=)(`Y0DZ````$DQ]40Q
MZ4V-K`BAZ]EN3(G938G82<'H&TC!X05,"<&)R4V-1`T`3(GA2<'L`DC!X1Y%
MB<5,">%)B?2)]D@#M"3P````23',1#'@3(VD`J'KV6Y,B>A,B>I(P>H;2,'@
M!4@)T(G`28T4!$R)V$G!ZP)(P>`>08G43`G828G+B<E),<-(`XPD^````$4Q
MV$V)XTZ-A`:AZ]EN3(GF2<'K&TC!Y@5,"=Z)]DP!QDV)Z$G![0))P>`>08GS
M30GH28G%B<!(`X0D``$``$TQQ40QZDR-K!&AZ]EN3(G:3(G92,'I&TC!X@5(
M"<J)TDF-3!4`3(GB2<'L`DC!XAY!B<U,">)-B<1%B<!,`X0D"`$``$DQU$0Q
MYDV)[$B-M#"AZ]EN3(GH2<'L&TC!X`5,">")P$@!\$R)WDG!ZP)(P>8>08G$
M3`G>28G3B=)),?-$,=E-C9P(H>O9;DR)X4V)X$C!X05)P>@;2`.4)!`!``!,
M"<&)R4V-!`M,B>E)P>T"2,'A'D6)PTP)Z4F)]8GV2`.T)!@!``!),<U$,>A,
MC:P"H>O9;DR)V$R)VDC!ZAM(P>`%2`G0B<!)C50%`$R)X$G![`)(P>`>08G5
M3`G@28G,B<E(`XPD(`$``$DQQ$4QX$V)[$Z-A`:AZ]EN3(GN2<'L&TC!Y@5,
M">:)]DP!QDV)V$G!ZP))P>`>08GT30G828G#B<!-,<-$,=I,C9P1H>O9;DR)
MXDR)X4C!Z1M(P>(%2`G*B=))C0P33(GJ2<'M`DC!XAY!B<M,">I-B<5(`X0D
M*`$``$6)P$DQU4P#A"0P`0``1#'N38G=2(VT,*'KV6Y,B=A)P>T;2,'@!4P)
MZ(G`2`'P3(GF2<'L`DC!YAY!B<5,">9)B=2)TD@#E"0X`0``23'T1#'A38VD
M"*'KV6Y,B>E-B>A)P>@;2,'A!4P)P8G)38T$#$R)V4G!ZP)(P>$>18G$3`G9
M28GSB?9(`[0D0`$``$DQRT0QV$V)XTB-E`*AZ]EN3(G@2<'K&TC!X`5,"=A$
MC1P03(GH2<'M`DC!X!Y,">A)B<V)R4DQQ8G"13'H38G=3HV$!J'KV6Y,B=Y(
MP>8%2<'M&TP)[DR+K"1(`0``1HTT!DV)X$G![`))P>`>30G@3`G`1(G&28G$
M2(G02"'P32'<20G$N-R\&X])`<5,`>E-B?5)`<Q,B?%)P>T;2,'A!4P)Z4:-
M+"%,B=E)P>L"28GT2,'A'DP)V4&)RTD)R$TAW$TA\$T)X$R+I"10`0``20'$
M3`'B38GL20'03(GJ2<'L&TC!X@5,">)&C20"3(GR2<'N`DC!XAY,"?)-B=Y(
M"=%!B=!-(<9,(>E,"?%,B[0D6`$``$D!QDP!]DV)YD@!\4R)YDG![AM(P>8%
M3`GV1(TT#DR)[DG![0)(P>8>3`GN38G%B?%("?))(<U,(>),">I,BZPD8`$`
M`$D!Q4T!ZTV)]4P!VDV)\TG![1M)P>,%30GK18TL$TV)XTG![`))P>,>30GC
M28G,1(G:3`G>22'43"'V3`GF3(ND)&@!``!)`<1-`>!-B>Q,`<9-B>A)P>P;
M2<'@!4T)X$6-)#!-B?!)P>X"2<'@'DT)\$F)UD2)QDT)PTDA]DTAZTT)\TR+
MM"1P`0``20'&3`'Q38GF20'+3(GA2<'N&TC!X05,"?%&C3093(GI2<'M`DC!
MX1Y,">E)B?5!B<M)"<A-(=U-(>!-">A,BZPD>`$``$D!Q4P!ZDV)]4D!T$R)
M\DG![1M(P>(%3`GJ1HTL`DR)XDG![`)(P>(>3`GB38G<08G02`G13"'Q32'$
M3`GA3(ND)(`!``!)`<1,`>9-B>Q(`?%,B>Y)P>P;2,'F!4P)YD2-)`Y,B?9)
MP>X"2,'F'DP)]DV)QHGQ2`GR22'.3"'J3`GR3(NT)(@!``!)`<9-`?--B>9,
M`=I-B>-)P>X;2<'C!4T)\T6--!--B>M)P>T"2<'C'DT)ZTF)S42)VDP)WDDA
MU4PAYDP)[DR+K"20`0``20'%30'H38GU3`'&38GP2<'M&TG!X`5-">A%C2PP
M38G@2<'L`DG!X!Y-">!)B=1$B<9-"<-)(?1-(?--">-,BZ0DF`$``$D!Q$P!
MX4V)[$D!RTR)Z4G![!M(P>$%3`GA1HTD&4R)\4G![@)(P>$>3`GQ28GV08G+
M20G(32'>32'H30GP3(NT)*`!``!)`<9,`?)-B>9)`=!,B>))P>X;2,'B!4P)
M\D:--`),B>I(P>(>2<'M`DP)ZDV)W4&)T$@)T4TAQ4PAX4P)Z4R+K"2H`0``
M20'%3`'N38GU2`'Q3(GV2<'M&TC!Y@5,">Y$C2P.3(GF2<'L`DC!YAY,">9-
MB<2)\4@)\DDAS$PA\DP)XDR+I"2P`0``20'$30'C38GL3`':38GK2<'L&TG!
MXP5-">--B?1)P>X"2<'D'D$!TTT)]$F)SD2)XDP)YDDAUDPA[DP)]DR+M"2X
M`0``20'&30'P38G>3`'&38G82<'N&TG!X`5-"?!%C30P38GH2<'M`DG!X!Y-
M">A)B=5$B<9-"<1)(?5-(=Q-">Q,BZPDP`$``$D!Q4P!Z4V)]4D!S$R)\4G!
M[1M(P>$%3`GI00',3(G92<'K`DC!X1Y,"=E)B?-!B<])"<A-(?M-(?!-"=A,
MBYPDR`$``$D!PTP!VDV)XTD!T$R)XDC!X@5)P>L;3`G:38GS2<'N`DG!XQY&
MC2P"3(GZ30GS18G>3`G93"'R3"'A2`G12(N4)-`!``!(`<)(`=9,B>I(`?%,
MB>Y(P>(%2,'N&T@)\DR)YDG![`)(P>8>1(T$"DR)\DP)YDR)P4&)]$D)\TC!
MZ1M,(>)-(>M)"=-(BY0DV`$``$@!PDP!^DD!TTR)PDC!X@5("<I,B>E)P>T"
M2,'A'HG23`GI3`':38GE2`G.08G/2`.$).`!``!!B=--(?U,(<9,">Y)B<5,
MB=A-`?5(P>@;20'U3(G>2,'F!4@)QDR)P$G!Z`)(P>`>B?9)"<"XUL%BRDP!
M[DPQP4&)]4V)QD6)P#'*2(N,).@!``!(`<%)`<Q*C0PB3(GJ38GL2<'L&TC!
MX@5,">*)TD@!RDR)V4G!ZP)(P>$>08G420G+2(N,)/`!``!-,=Y(`<%$,?9)
M`<],B>%)`?=,B>9(P>$%2,'N&T@)\8G)28TT#TR)Z4G![0)(P>$>08GV20G-
M2(N,)/@!``!(`<%.C3P!38G83(GQ18G;33'H2,'I&T0QPDV)\$G!X`5,`?I)
M"<A,B>%)P>P"18G`2,'A'DD!T$B+E"0``@``3`GA18G'2`'"3`':38GK18GM
M23'+1#'>38G[2`'63(GZ2<'C!4C!ZAM)"=-,B?))P>X"2,'B'D6)VTD)UDB+
ME"0(`@``20'S2(NT)!`"``!%B=Q(`<))`=5(B<J)R4PQ\D$QT$R)XDT!Z$V)
MY4G!Y05(P>H;2`'&20G53(GZ2<'O`D@!\4C!XAY%B>U,B?9%B?9,"?I-`>A(
M,=9%B<5!,?-,B>Y)`<M,B>E(P>X;2,'A!4@)\4R)[DG![0*)R4C!YAY)`<M,
MB>%)P>P"3`GN2,'A'D6)WTD)S$B+C"08`@``2`'!20'.2(G1B=),,>%!,<A,
MB?E-`?!-B?Y(P>D;2<'F!4D)SDB+C"0@`@``18GV2`'!30'P2`'*3(GA18G&
M18GD2#'Q03'+3(GQ20'33(GR2,'I&TC!X@5("<I,B?%)P>X"B=)(P>$>20'3
M3(GZ2<'O`DP)\4C!XAY%B=U)"==(BY0D*`(``$@!PDD!U$B)\HGV3#'Z03'0
M3(GJ30'@38GL2,'J&TG!Y`5)"=1(BY0D,`(``$6)Y$@!PDT!X$@!UDR)^D6)
MQ$6)_T@QRD$QTTR)XDD!\TR)YDC!ZAM(P>8%2`G63(GJB?9)`?-(P>(>2(NT
M)$`"``!)P>T"18G>20G52(N4)#@"``!(`<9(`<))`==(B<J)R4PQZD@!\4R)
M[D6)[4$QT$R)\DT!^$V)]TC!ZAM)P><%20G73(GB2<'L`DC!XAY%B?],">)-
M`?A(,=9%B<=!,?-,B?Y)`<M,B?E(P>X;2,'A!4@)\4R)_HG)20'+3(GQ2<'N
M`DC!X1Y%B=Q)"<Y(BXPD2`(``$@!P4D!S4B)T8G23#'Q03'(3(GA30'H38GE
M2<'E!4C!Z1M)P>\"20G-2(N,)%`"``!(P>8>3`G^18GM2`'!30'H2`'*3(GQ
M18G%18GV2#'Q03'+3(GI20'33(GJ2,'I&TC!X@5("<I,B>E)P>T"B=)(P>$>
M20'33(GB2<'L`DP)Z4C!XAY%B=])"=1(BY0D6`(``$@!PDD!UDB)\HGV3#'B
M03'03(GZ30'P38G^2,'J&TG!Y@5)"=9(BY0D8`(``$6)]D@!PDT!\$@!UDR)
MXD6)QD6)Y$@QRD$QTTR)\DD!\TR)]DC!ZAM(P>8%2`G63(GZ2<'O`DC!XAZ)
M]DD)UTB+E"1H`@``20'S18G=2`'"20'42(G*B<E,,?I!,=!,B>I-`>!-B>Q(
MP>H;2<'D!4D)U$R)\DG![@)(P>(>18GD20G62(N4)'`"``!-`>!$B<9-B?1(
M`<)(`=%,B?I%B?],,?)%B?9!,=-(B?))`<M(B?%(P>H;2,'A!4@)T8G)3`'9
M38GK2<'C'DG![0*)RDT)W4R+G"1X`@``33'L20'#13'@2`.$)(`"``!-`=])
MB=--`<=)B=!)P>L;2<'@!4T)V$F)\TC![@))P>,>10'X3`G>28G32,'J`D4!
MP4G!XQY,B4\(20G32HT4,$R)Z$0#;R!(,?!$`=L![DR);R`QP4B)7Q!(C00*
M3(G"3(G!2(EW&$C!X@5(P>D;2`G*`=!!`<),B1=(BX0DB`(``&1(,P0E*```
M`'0%Z&_2__](@<28`@``6UU!7$%=05Y!7\-0OX````#H`M#__[J)J\WON?[<
MNIB^\.'2PTC'``$C16=(B5`(2(E($$C'0!AV5#(02(EP($C'0"@`````2,=`
M,`````#'0'@`````6L-!5DACPD%5051)B<154TB+3RA(B?N-%,%(.=%V!$C_
M1S!(P>@=2`%#,$AC0WA(C6LX2(E3*(7`=%*Z0````"G"03G400].U$@!Z$AC
MRD@Y\',+2(T\"$@Y_G,"#PM,C2P.2#GP=@5,.>AR\$B)Q_.DBT-X`=")0WB#
M^$!U>$B)WT$IU.@>Z?__3(GN3(UK>$&#_#]^,T@Y[G8%3#GN<KQ(.>Y,C79`
M<P5,.?5RKKD0````2(GO08/L0/.E2(G?Z./H__],B?;KQTECS$@Y[G8*2(U$
M#0!(.<9R@4@Y[G,-2(T$#D@YQ0^";____TB)[_.D1(EC>%M=05Q!74%>PT%6
M055!5$R-9CA52(G]4TB+1BA(B?-$BVXH1(MV,$C!Z`.#X#]!#\U!#\Z-<`%(
MF$ACUL9$`SB`3`'B@_XX?B2Y0````#'`2(G7*?'SJDB)W^A2Z/__N0X````Q
MP$R)Y_.KZPZY.````#'`2(G7*?'SJD2)<W!(B=]$B6MTZ";H__](BP-(B=](
MP>@8B$4`2(L#2,'H$(A%`4B+`TC!Z`B(10)(BP.(10-(BT,(2,'H&(A%!$B+
M0PA(P>@0B$4%2(M#"$C!Z`B(109(BT,(B$4'2(M#$$C!Z!B(10A(BT,02,'H
M$(A%"4B+0Q!(P>@(B$4*2(M#$(A%"TB+0QA(P>@8B$4,2(M#&$C!Z!"(10U(
MBT,82,'H"(A%#DB+0QB(10](BT,@2,'H&(A%$$B+0R!(P>@0B$412(M#($C!
MZ`B(11)(BT,@6XA%$UU!7$%=05[I.\___U5(B>532(T=3V@``%)(BP-(@_C_
M=`C_T$B#ZPCK[UA;7<-0Z!/2__]8PP``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+BX`)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`&5X90`O<')O8R\E:2\E<P!005)?5$5-4`!0
M05)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$52
M3$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%2
M7T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?
M5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?4$%42`!365-414T`+W1M
M<`!54T52`%5315).04U%`"4P,G@`<&%R+0`E<R5S)7,E<P`E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`<&%R
M;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M
M)74M)74E<P!414U01$E2`%1-4`!!4D=6`!@`<&5R;``P`%!!4CHZ4&%C:V5R
M.CI615)324].`#$N,#0Y`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T
M;W)Y`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H`+64`+2T`979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!
M4E]-04=)0RP@)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@
M)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H
M"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T
M96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*
M<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF
M:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY
M("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G
M.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B
M86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M
M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B1005)?
M34%'24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D[
M"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H
M"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D[
M"E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD[
M"GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G
M/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68[
M"FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T
M("H@,3`R-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S
M:7IE*2!["B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ
M92`E("1C:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@
M)&T["GT@96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE
M.PI]"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:RA?1D@L("1M86=I
M8U]P;W,L(#`I.PIR96%D*%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG
M=&@H)%!!4E]-04=)0RDI.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("10
M05)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*
M)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P
M;W,@/"`P.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(
M+"`D8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH
M(DXB+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U
M:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F
M:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D
M969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M
M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,
M24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U
M;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65]
M(#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN
M86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H
M<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@9&5L971E("1R97%U
M:7)E7VQI<W1[)&UO9'5L97T@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@
M(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@
M86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&
M:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I
M;G0@)&9H("1I;F9O+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@
M)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1I;F9O
M+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L
M("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2([
M"F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*
M=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES
M="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE
M(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@
M>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N
M;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID
M96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S
M("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A
M<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M
M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2
M155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N
M;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%2
M1U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES
M=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU
M("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(*
M*3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI
M9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*
M?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I
M;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q
M<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@
M0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B
M=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE
M;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@
M*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q
M("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E
M;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L
M;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@
M)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD
M,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E
M<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S
M<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*
M97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H
M)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`
M05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D
M9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B
M.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D
M:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!
M4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD[
M"F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q
M(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/
M.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W
M-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D
M9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@
M,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@
M;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\[
M"FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*
M;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E
M<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL
M96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@
M4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII
M;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@
M>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE
M<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B
M:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O
M;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y
M<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<
M15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R
M*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<
M6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE
M;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER
M+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N
M86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J
M;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F
M*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*
M;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL
M93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO
M<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N
M86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D[
M"GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B
M1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT
M*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P
M96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@/2`D8W1X+3YH
M97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^
M<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M
M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!
M1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I[
M"FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M
M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/
M.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I
M.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U
M=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N
M("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O
M+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM
M>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2`O
M+R`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD
M9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M"GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F
M:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@
M;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T
M96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@
M)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM
M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.
M?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG
M=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@
M/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``````7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("```````````'!E<FQX<VDN8P``
M``$;`SO@````&P```+R"___\````3(;__R0!``!DAO__M`0``%B)__\\`0``
MWHG__X0!```6BO__G`$``(2*___$`0``0(S__P@"``!_C?__3`(``/^-__]P
M`@``*H[__X@"``!NCO__H`(``%2/___,`@``68___^`"```-D?__+`,``".1
M__]``P``PI'__U@#``!FD___?`,``*J3__^4`P``P9/__ZP#``!7E/__Y`,`
M`"F:__]$!```=9W__X`$``##G?__W`0``,^S__\H!0``';3__T`%```;M?__
M?`4``!0``````````7I2``%X$`$;#`<(D`$``"0````<````N('__Y`#````
M#A!&#AA*#PMW"(``/QH[*C,D(@`````4````1````""%__\8````````````
M``!$````7````!2(__^&`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9#
M#CB#!T$.0`)K#CA$#C!!#BA"#B!"#AA"#A!"#@@4````I````%*(__\X````
M`$0.(',."``D````O````'*(__]N`````$$.$(8"00X8@P-'#C`"8@X800X0
M00X(0````.0```"XB/__O`$```!"#A".`D(.&(T#0@X@C`1!#BB&!40.,(,&
M1PY``Z$!#C!!#BA!#B!"#AA"#A!"#@@```!`````*`$``#"*__\_`0```$(.
M$(X"0@X8C0-"#B",!$$.*(8%00XP@P9'#M`!`R<!#C!!#BA!#B!"#AA"#A!"
M#@@``"````!L`0``*XO__X``````00X0@P)*#K`!`G,.$$$."````!0```"0
M`0``AXO__RL`````00X05`X(`!0```"H`0``FHO__T0`````00X0:@X(`"@`
M``#``0``QHO__^8`````00X0A@)!#AB#`T<.L$`"V@X800X000X(````$```
M`.P!``"`C/__!0````````!(``````(``'&,__^T`0```$(.$(\"0@X8C@-"
M#B"-!$(.*(P%00XPA@9+#CB#!TH.X"$#BP$..$$.,$$.*$(.($(.&$(.$$(.
M"```$````$P"``#9C?__%@`````````4````8`(``-N-__^?``````*'#A!4
M#@@@````>`(``&*.__^D`0```$$.$(,"4`Y``Y$!#A!!#@@````4````G`(`
M`.*/__]$`````$H.$'(."``4````M`(```Z0__\7`````$$.$%4."``T````
MS`(```V0__^6`````$(.$(P"0PX8A@-+#B"#!`)P"@X82`X01`X(10M!#AA!
M#A!"#@@``%P````$`P``:Y#__](%````0@X0CP).#AB.`T(.((T$10XHC`5!
M#C"&!D$..(,'1PZ0@P(#1P4.F(,"2@Z@@P)0#IB#`D$.D(,"`D4..$$.,$$.
M*$(.($(.&$(.$$(."#@```!D`P``W97__TP#````0@X0C0)"#AB,`T$.((8$
M00XH@P5!#C`#/@,.*$$.($$.&$(.$$(."````#````"@`P``[9C__TX`````
M00X0A@)!#AB#`T0.('H*#AA$#A!!#@A%"T$.&$$.$$$."``D````U`,``*B!
M__^R`0```$$.$(,"1`XP`ZD!#A!##@@`````````2````/P#``#?F/__#!8`
M``!"#A"/`D0.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`^X5#CA!#C!!
M#BA"#B!"#AA"#A!"#@@``!0```!(!```GZ[__TX`````00X0`DP."#@```!@
M!```U:[___X`````0@X0C@)%#AB-`T(.((P$1`XHA@5!#C"#!@+H#BA!#B!"
M#AA"#A!"#@@``#@```"<!```EZ___U8!````0@X0C@)"#AB-`T(.((P$10XH
MA@5$#C"#!@,X`0XH1`X@0@X80@X00@X(````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````__________\``````````/__________````````````````
M``````$``````````0`````````!`````````+("````````#P`````````W
M!`````````P``````````"`````````-`````````.=3````````]?[_;P``
M``"0`@````````4`````````H`P````````&`````````(@#````````"@``
M``````!5!`````````L`````````&``````````5````````````````````
M`P````````#HO0````````(`````````0`4````````4``````````<`````
M````%P````````#`$@````````<`````````^!`````````(`````````,@!
M````````"0`````````8`````````!@```````````````````#[__]O````
M``$```@`````^?__;P`````'````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````2+P`````````````````````````````)B``````
M```V(````````$8@````````5B````````!F(````````'8@````````AB``
M``````"6(````````*8@````````MB````````#&(````````-8@````````
MYB````````#V(`````````8A````````%B$````````F(0```````#8A````
M````1B$```````!6(0```````&8A````````=B$```````"&(0```````)8A
M````````IB$```````"V(0```````,8A````````UB$```````#F(0``````
M`/8A````````!B(````````6(@```````"8B````````-B(```````!&(@``
M`````%8B````````9B(```````!V(@```````(8B````````EB(```````"F
M(@```````+8B````````QB(```````#6(@```````.8B````````]B(`````
M```&(P```````!8C````````)B,````````V(P```````$8C````````5B,`
M``````!F(P```````'8C````````AB,```````"6(P``````````````````
M````````````````````````````````````````````````````````````
M````````````````P````````````````````````````````````````.)@
M````````VV`````````>8@```````/A@````````)F(`````````````````
M`/____\`````NV(```````!'0T,Z("A!;'!I;F4@."XS+C`I(#@N,RXP```N
M<VAS=')T86(`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR
M96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`
M+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S
M`"YD871A+G)E;"YR;P`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM96YT````
M````````````````````````````````````````````````````````````
M``````````````````````````L````!`````@````````!P`@```````'`"
M````````&0````````````````````$````````````````````3````]O__
M;P(`````````D`(```````"0`@```````/@``````````P`````````(````
M````````````````'0````L````"`````````(@#````````B`,````````8
M"0````````0````!````"``````````8`````````"4````#`````@``````
M``"@#````````*`,````````500```````````````````$`````````````
M```````M````!`````(`````````^!````````#X$````````,@!````````
M`P`````````(`````````!@`````````-P````0```!"`````````,`2````
M````P!(```````!`!0````````,````3````"``````````8`````````$$`
M```!````!@``````````(``````````@````````#0``````````````````
M``$````````````````````\`````0````8`````````$"`````````0(```
M`````)`#```````````````````0`````````!``````````1P````$````&
M`````````*`C````````H",````````8````````````````````"```````
M```(`````````%`````!````!@````````"X(P```````+@C````````+S``
M``````````````````$```````````````````!6`````0````8`````````
MYU,```````#G4P````````@````````````````````!````````````````
M````7`````$````"``````````!@`````````&````````!2/0``````````
M````````"````````````````````&0````!`````@````````!4G0``````
M`%2=````````Y`````````````````````0```````````````````!R````
M`0````(`````````.)X````````XG@```````-@$```````````````````(
M````````````````````?`````$````#`````````""\````````(*P`````
M```0````````````````````"````````````````````(,````!`````P``
M```````PO````````#"L````````$`````````````````````@`````````
M``````````"*`````0````,`````````0+P```````!`K`````````@`````
M```````````````(````````````````````EP````8````#`````````$B\
M````````2*P```````"@`0````````0`````````"``````````0````````
M`$L````!`````P````````#HO0```````.BM````````&`(`````````````
M``````@`````````"`````````"@`````0````,``````````,``````````
ML````````&`````````````````````@````````````````````I@````@`
M```#`````````&#`````````8+````````"H$```````````````````(```
M`````````````````*L````!````,````````````````````&"P````````
M&@````````````````````$``````````0`````````!`````P``````````
M``````````````!ZL````````+0````````````````````!````````````
&````````
